ENDPOINT = "https://third.zcsazzurroportal.com:19003"
AUTH_KEY = "Authorization"
AUTH_VALUE = "Zcs eHWAeEq0aYO0"
CLIENT_AUTH_KEY = "client"
CONTENT_TYPE = "application/json"
REQUEST_TIMEOUT = 5

HISTORIC_DATA_KEY = "historicData"
HISTORIC_DATA_COMMAND = "historicData"

REALTIME_DATA_KEY = "realtimeData"
REALTIME_DATA_COMMAND = "realtimeData"

DEVICES_ALARMS_KEY = "deviceAlarm"
DEVICES_ALARMS_COMMAND = "deviceAlarm"

COMMAND_KEY = "command"
PARAMS_KEY = "params"
PARAMS_THING_KEY = "thingKey"
PARAMS_REQUIRED_VALUES_KEY = "requiredValues"
PARAMS_START_KEY = "start"
PARAMS_END_KEY = "end"

RESPONSE_SUCCESS_KEY = "success"
RESPONSE_VALUES_KEY = "value"

# Values of required values
REQUIRED_VALUES_ALL = "*"
REQUIRED_VALUES_SEP = ","
